@@ -5,8 +5,8 @@ use warnings;
 
 use base 'Mojo::Command';
 
-use Mojo::ByteStream 'b';
 use Mojo::Loader;
+use Mojo::Util qw/camelize decamelize/;
 
 __PACKAGE__->attr(hint => <<"EOF");
 
@@ -65,7 +65,9 @@ sub run {
         for my $namespace (@{$self->namespaces}) {
 
             # Generate module
-            my $try = $namespace . '::' . b($name)->camelize;
+            my $camelized = $name;
+            camelize $camelized;
+            my $try = "$namespace\::$camelized";
 
             # Load
             if (my $e = Mojo::Loader->load($try)) {
@@ -129,7 +131,7 @@ sub run {
 
         # Generate name
         my $name = $command->[0];
-        $name = b($name)->decamelize;
+        decamelize $name;
 
         # Add to list
         my $l = length $name;
